==> shardingsphere-authority-api-5.3.2-sources.jar: org/apache/shardingsphere/authority/config/AuthorityRuleConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.authority.config;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.infra.config.algorithm.AlgorithmConfiguration;
import org.apache.shardingsphere.infra.config.rule.scope.GlobalRuleConfiguration;
import org.apache.shardingsphere.infra.metadata.user.ShardingSphereUser;

import java.util.Collection;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * Authority rule configuration.
 */
@RequiredArgsConstructor
@Getter
public final class AuthorityRuleConfiguration implements GlobalRuleConfiguration {
    
    private final Collection<ShardingSphereUser> users;
    
    private final AlgorithmConfiguration authorityProvider;
    
    private final String defaultAuthenticator;
    
    private final Map<String, AlgorithmConfiguration> authenticators = new LinkedHashMap<>();
}

==> shardingsphere-authority-api-5.5.0-sources.jar: org/apache/shardingsphere/authority/config/AuthorityRuleConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.shardingsphere.authority.config;

import lombok.Getter;
import lombok.RequiredArgsConstructor;
import org.apache.shardingsphere.infra.algorithm.core.config.AlgorithmConfiguration;
import org.apache.shardingsphere.infra.config.rule.scope.GlobalRuleConfiguration;
import org.apache.shardingsphere.infra.metadata.user.ShardingSphereUser;

import java.util.Collection;
import java.util.Map;

/**
 * Authority rule configuration.
 */
@RequiredArgsConstructor
@Getter
public final class AuthorityRuleConfiguration implements GlobalRuleConfiguration {
    
    private final Collection<ShardingSphereUser> users;
    
    private final AlgorithmConfiguration privilegeProvider;
    
    private final Map<String, AlgorithmConfiguration> authenticators;
    
    private final String defaultAuthenticator;
}
